@@ -2,10 +2,10 @@
 
 PRODUCT="Prince"
 PROGRAM="prince"
-VERSION="12.5.1"
-WEBSITE="http://www.princexml.com"
+VERSION="14.2"
+WEBSITE="https://www.princexml.com"
 
-prefix=/usr/local
+prefix=${1:-/usr/local}
 
 base=$( dirname "$0" )
 
